<?php
// {{{ requires
require_once CLASS_EX_REALDIR . 'page_extends/admin/LC_Page_Admin_Ex.php';

class LC_Page_Admin_Contents_Upload_Photo extends LC_Page_Admin_Ex {

    /**
     * Page を初期化する.
     *
     * @return void
     */
    public function init() {
        parent::init();
        $this->tpl_mainpage = 'contents/upload_photo.tpl';
        $this->tpl_mainno = 'contents';
        $this->tpl_subno = 'upload_photo';
        $this->tpl_maintitle = 'コンテンツ管理';
        $this->tpl_subtitle = '画像アップロード';
        $masterData = new SC_DB_MasterData_Ex();
        $this->arrDISP = $masterData->getMasterData('mtb_disp');
		$this->arrOPENWIN = $masterData->getMasterData('mtb_openwin');
    }

    /**
     * Page のプロセス.
     *
     * @return void
     */
    public function process() {
        $this->action();
        $this->sendResponse();
    }

    /**
     * Page のアクション.
     *
     * @return void
     */
    public function action() {

        $objFormParam = new SC_FormParam_Ex();
        $mode = $this->getMode();
        $this->lfInitParam($mode, $objFormParam);

        // ファイル管理クラス
        $this->objUpFile = new SC_UploadFile(IMAGE_TEMP_REALDIR, IMAGE_SAVE_REALDIR);
        // ファイル情報の初期化
        $this->objUpFile = $this->lfInitFile();
        // Hiddenからのデータを引き継ぐ
        $this->objUpFile->setHiddenFileList($_POST);

        switch ($mode) {
            case 'edit':
                $objFormParam->setParam($_REQUEST);
                $objFormParam->convParam();
                $post = $objFormParam->getHashArray();
                $this->arrErr = $this->lfCheckError($post, $objFormParam);
                if (count($this->arrErr) == 0) {
                    $this->lfRegistData($post['topimg_id'], $_SESSION['member_id'], $objFormParam);
                    $this->objUpFile->moveTempFile();
                    $this->tpl_onload = "location.href = './upload.php'; return;";
                }
                $this->tpl_topimg_id = $post['topimg_id'];
                break;
            // 画像のアップロード
            case 'upload_image':
                $objFormParam->setParam($_REQUEST);
                $objFormParam->convParam();
                $post = $objFormParam->getHashArray();
                // ファイル存在チェック
                $this->arrErr = $this->objUpFile->checkExists($post['image_key']);
                // 画像保存処理
                $this->arrErr[$post['image_key']] = $this->objUpFile->makeTempFile($post['image_key']);
                $this->tpl_topimg_id = $post['topimg_id'];
                break;
            // 画像の削除
            case 'delete_image':
                $objFormParam->setParam($_REQUEST);
                $objFormParam->convParam();
                $this->arrErr = $objFormParam->checkError();
                $post = $objFormParam->getHashArray();
                if (count($this->arrErr) == 0) {
                    $this->objUpFile->deleteFile($post['image_key']);
                }
                $this->tpl_topimg_id = $post['topimg_id'];
                break;

            case 'pre_edit':
                $objFormParam->setParam($_REQUEST);
                $objFormParam->convParam();
                $this->arrErr = $objFormParam->checkError();
                $post = $objFormParam->getHashArray();
                if (count($this->arrErr) == 0) {
                    $arrRet = $this->lfGetData($post['topimg_id']);

					$objFormParam->addParam('公開・非公開', 'status', INT_LEN, 'n', array('EXIST_CHECK', 'NUM_CHECK', 'MAX_LENGTH_CHECK'));
                    $objFormParam->addParam('リンクURL', 'url', MLTEXT_LEN, 'KVa', array('MAX_LENGTH_CHECK'));
					$objFormParam->addParam('リンク先表示', 'openwin', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));
                    $objFormParam->setParam($arrRet);

                    $this->objUpFile->setDBFileList($arrRet);
                }
                $this->tpl_topimg_id = $post['topimg_id'];
                break;
            default:
                break;
        }

        $this->arrForm = $objFormParam->getFormParamList();

        // FORM表示用配列を渡す。
        $this->arrFile = $this->objUpFile->getFormFileList(IMAGE_TEMP_URLPATH, IMAGE_SAVE_URLPATH);
        // HIDDEN用に配列を渡す。
        $this->arrHidden = array_merge((array)$this->arrHidden, (array)$this->objUpFile->getHiddenFileList());
		
    }

    /* ファイル情報の初期化 */
    public function lfInitFile() {
        $this->objUpFile->addFile('メイン画像', 'main_image', array('gif','jpeg','jpg','png'), IMAGE_SIZE, false, TOP_MAIN_WIDTH, TOP_MAIN_HEIGHT);
        $this->objUpFile->addFile('サムネイル画像', 'thumbnail_image', array('gif','jpeg','jpg','png'), IMAGE_SIZE, false, TOP_THUMBNAIL_WIDTH, TOP_THUMBNAIL_HEIGHT);
        return $this->objUpFile;
    }

    /* パラメーター情報の初期化 */
    public function lfInitParam($mode, &$objFormParam) {

        switch ($mode) {
            case 'edit':
                $objFormParam->addParam('ID', 'topimg_id', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));
				$objFormParam->addParam('公開・非公開', 'status', INT_LEN, 'n', array('EXIST_CHECK', 'NUM_CHECK', 'MAX_LENGTH_CHECK'));
                $objFormParam->addParam('リンクURL', 'url', MLTEXT_LEN, 'KVa', array('MAX_LENGTH_CHECK'));
				$objFormParam->addParam('リンク先表示', 'openwin', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));

                break;
            case 'upload_image':
            case 'delete_image':
                $objFormParam->addParam('ID', 'topimg_id', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));
                $objFormParam->addParam('画像キー', 'image_key', STEXT_LEN, 'KVa', array('EXIST_CHECK', 'MAX_LENGTH_CHECK'));
				$objFormParam->addParam('公開・非公開', 'status', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));
                $objFormParam->addParam('リンクURL', 'url', MLTEXT_LEN, 'KVa', array('MAX_LENGTH_CHECK'));
				$objFormParam->addParam('リンク先表示', 'openwin', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));

                break;
            case 'pre_edit':
                $objFormParam->addParam('ID', 'topimg_id', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));
                break;

            default:
				$objFormParam->addParam('公開・非公開', 'status', INT_LEN, 'n', array('EXIST_CHECK', 'NUM_CHECK', 'MAX_LENGTH_CHECK'));
                $objFormParam->addParam('リンクURL', 'url', MLTEXT_LEN, 'KVa', array('MAX_LENGTH_CHECK'));
				$objFormParam->addParam('リンク先表示', 'openwin', INT_LEN, 'n', array('NUM_CHECK', 'MAX_LENGTH_CHECK'));

                break;

        }

    }

    /* DBからデータを読み込む */
    public function lfGetData($topimg_id) {
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $where = 'topimg_id = ?';
        $arrRet = $objQuery->select('*', 'dtb_topimg', $where, array($topimg_id));
        return $arrRet[0];
    }

    /* DBへデータを登録する */
    public function lfRegistData($topimg_id = '', $member_id, &$objFormParam) {

        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $sqlval = $objFormParam->getHashArray();
        $arrRet = $this->objUpFile->getDBFileList(); // ファイル名の取得
        $sqlval = array_merge($sqlval, $arrRet);
        $sqlval['update_date'] = 'CURRENT_TIMESTAMP';

        // 新規登録
        if ($topimg_id == '') {
            // INSERTの実行
            $sqlval['creator_id'] = $member_id;
            $sqlval['rank'] = $objQuery->max('rank', 'dtb_topimg') + 1;
            $sqlval['create_date'] = 'CURRENT_TIMESTAMP';
            $sqlval['topimg_id'] = $objQuery->max('topimg_id', 'dtb_topimg') + 1;
            $objQuery->insert('dtb_topimg', $sqlval);
        // 既存編集
        } else {
            $where = 'topimg_id = ?';
            $objQuery->update('dtb_topimg', $sqlval, $where, array($topimg_id));
        }
    }

    /* 入力内容のチェック */
    public function lfCheckError($post, $objFormParam) {

        // DBのデータを取得
        $arrPaymentData = $this->lfGetData($post['topimg_id']);

        // 入力データを渡す。
        $arrRet =  $objFormParam->getHashArray();
        $objErr = new SC_CheckError_Ex($arrRet);
        $objErr->arrErr = $objFormParam->checkError();

        return $objErr->arrErr;
    }

}
